#!/usr/bin/perl -w

use lib qw(.);
use WhoDat;
use Getopt::Long;
use Pod::Usage;
use File::Basename qw(basename);

##======================================================================
## Globals
##======================================================================
our $modelfile = '-';
our $nsents    = 1;
our $outfile   = '-';

our $progname = basename($0);

##======================================================================
## Options
##======================================================================
GetOptions(##-- General
	   'h|help' => \$help,
	   ##-- Model,
	   'm|model=s' => \$modelfile,
	   ##-- Generation
	   'n|nsents=i' => \$nsents,
	   'o|out|output=s' => \$outfile,
	  );

pod2usage({
	   -exitval=>0,
	   -verbose=>0
	  }) if ($help);

if ($version) {
  print STDERR "$progname (WhoDat v$WhoDat::VERSION) by Bryan Jurish\n";
  exit 0 if ($version);
}


##======================================================================
## MAIN
##======================================================================

##-- open output file
open(OUT,">$outfile")
  or die("$progname: could not open output file '$outfile': $!");

##-- load model file
our $ngs = WhoDat::Ngrams->loadFile($modelfile)
  or die("$progname: could not load model file '$modelfile': $!");

##-- generate
while ($nsents > 0) {
  $ngs->reset;
  $q = undef;
  while (1) {
    $q = $ngs->next;
    last if ($q eq "__\$");
    print OUT $q, "\n";
  }
  print OUT "\n";
  $nsents--;
}

close OUT;

__END__

##======================================================================
## Pods
##======================================================================


=head1 NAME

whodat-gensyn.perl - generate syntactic templates from a WhoDat syntax model

=head1 SYNOPSIS

 whodat-gensym.perl [OPTIONS]

 General Options:
   -help
   -version

 Model Options:
   -model  MODEL_FILE

 I/O Options:
   -output OUTPUT_FILE
   -nsents NUMBER_OF_SENTENCES

=cut

###############################################################
## OPTIONS
###############################################################
=pod

=head1 OPTIONS

=cut

###############################################################
# General Options
###############################################################
=pod

=head2 General Options

=over 4

=item -help

Display a brief help message and exit.

=item -version

Display version information and exit.

=back

=cut


###############################################################
# Model Options
###############################################################
=pod

=head2 Model Options

=over 4

=item -model MODEL_FILE

Use syntax model file MODEL_FILE.
MODEL_FILE should be an n-gram parameter file (*.123)
as generated by the mootrain(1) program.
Default: '-' (read model file from stdin).

=back

=cut

###############################################################
# I/O Options
###############################################################
=pod

=head2 I/O Options

=over 4

=item -output OUTPUT_FILE

Write output to OUTPUT_FILE.
Default='-' (write to stdout).

=item -nsents NUMBER_OF_SENTENCES

Generate NUMBER_OF_SENTENCES sentences.
Default=1.

=back

=cut


###############################################################
# Bugs and Limitations
###############################################################
=pod

=head1 BUGS AND LIMITATIONS

Probably many.

=cut


###############################################################
# Footer
###############################################################
=pod

=head1 ACKNOWLEDGEMENTS

Perl by Larry Wall.

=head1 AUTHOR

Bryan Jurish E<lt>moocow@ling.uni-potsdam.deE<gt>

=head1 SEE ALSO

perl(1).

=cut
